@@ -1,6 +1,6 @@
 /*
  * backend.h -- Interface exported by XBoard back end
- * $Id: backend.h,v 1.47 2001/12/09 23:02:59 mann Exp $
+ * $Id: backend.h,v 1.48 2001/12/15 22:50:49 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -233,7 +233,9 @@ typedef struct _CPS {
     int matchWins;
     char variants[MSG_SIZ];
     int analysisSupport;
+    int analyzing;
     int protocolVersion;
+    int initDone;
 } ChessProgramState;
 
 extern ChessProgramState first, second;
