@@ -1,6 +1,6 @@
 /*
  * xedittags.c -- Tags edit window, part of X front end for XBoard
- * $Id: xedittags.c,v 1.7 2000/12/17 01:55:48 mann Exp $
+ * $Id: xedittags.c,v 1.8 2001/12/09 23:02:59 mann Exp $
  *
  * Copyright 1995 Free Software Foundation, Inc.
  *
@@ -315,6 +315,7 @@ Widget TagsCreate(name, text, msg, mutable, callback)
     XtSetArg(args[j], XtNx, tagsX - appData.borderXoffset);  j++;
     XtSetArg(args[j], XtNy, tagsY - appData.borderYoffset);  j++;
     XtSetValues(shell, args, j);
+    XtSetKeyboardFocus(shell, textw);
 
     return shell;
 }
@@ -382,7 +383,6 @@ void EditTagsPopUp(tags)
     }
 
     XtPopup(editTagsShell, XtGrabNone);
-    XtSetKeyboardFocus(shellWidget, editTagsShell);
 
     editTagsUp = True;
     j = 0;
@@ -409,7 +409,6 @@ void TagsPopDown()
     XtSetArg(args[j], XtNy, &tagsY); j++;
     XtGetValues(w, args, j);
     XtPopdown(w);
-    XtSetKeyboardFocus(shellWidget, formWidget);
     XSync(xDisplay, False);
     tagsUp = editTagsUp = False;
     j = 0;
