@@ -1,6 +1,6 @@
 /*
  * xgamelist.c -- Game list window, part of X front end for XBoard
- * $Id: xgamelist.c,v 1.7 1999/12/04 01:53:01 mann Exp $
+ * $Id: xgamelist.c,v 1.8 2000/12/17 01:55:48 mann Exp $
  *
  * Copyright 1995 Free Software Foundation, Inc.
  *
@@ -51,6 +51,21 @@ extern char *getenv();
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#if USE_XAW3D
+#include <X11/Xaw3d/Dialog.h>
+#include <X11/Xaw3d/Form.h>
+#include <X11/Xaw3d/List.h>
+#include <X11/Xaw3d/Label.h>
+#include <X11/Xaw3d/SimpleMenu.h>
+#include <X11/Xaw3d/SmeBSB.h>
+#include <X11/Xaw3d/SmeLine.h>
+#include <X11/Xaw3d/Box.h>
+#include <X11/Xaw3d/MenuButton.h>
+#include <X11/Xaw3d/Text.h>
+#include <X11/Xaw3d/AsciiText.h>
+#include <X11/Xaw3d/Viewport.h>
+#else
 #include <X11/Xaw/Dialog.h>
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/List.h>
@@ -60,10 +75,10 @@ extern char *getenv();
 #include <X11/Xaw/SmeLine.h>
 #include <X11/Xaw/Box.h>
 #include <X11/Xaw/MenuButton.h>
-#include <X11/cursorfont.h>
 #include <X11/Xaw/Text.h>
 #include <X11/Xaw/AsciiText.h>
 #include <X11/Xaw/Viewport.h>
+#endif
 
 #include "common.h"
 #include "frontend.h"
